Welcome to rasterio/affine's documentation!
===========================================

This is the documentation of the latest development version at https://github.com/rasterio/affine .

.. include:: ../../README.rst

Module documentation
====================

.. automodule:: affine
   :members:

.. include:: ../../CHANGES.txt
.. include:: ../../AUTHORS.txt

License
=======

.. include:: ../../LICENSE.txt
   :literal:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
